

set -ex



rio --help
rio info /tmp/build/80754af9/rsync-recipes/rasterio-1.1.0-python_3.7-on-linux_64/test_data/test.tif
$PYTHON -m pytest -v -m "not wheel" -rxXs -k "not test_mp_no_main_env" tests
exit 0
